<p align="center">
  <a href=""><img src="https://raw.githubusercontent.com/sekaibot-dev/sekaibot/main/docs/public/logo.png" width="250" height="250" alt="sekaibot"></a>
</p>

<div align="center">

<img src="https://raw.githubusercontent.com/sekaibot-dev/sekaibot/main/docs/public/name.png" width="140" alt="sekaibot">

_-跨平台的 Python 异步渐进式机器人开发框架-_

</div>

<div align="center">
  <a href="https://raw.githubusercontent.com/AliceBotProject/alicebot/master/LICENSE">
    <img src="https://img.shields.io/github/license/AliceBotProject/alicebot" alt="license">
  </a>
  <a href="https://pypi.python.org/pypi/alicebot">
    <img src="https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fgithub.com%2FAliceBotProject%2Falicebot%2Fraw%2Fmaster%2Fpyproject.toml" alt="pypi">
  </a>
  <a href="https://pypi.python.org/pypi/alicebot">
    <img src="https://img.shields.io/pypi/v/alicebot" alt="pypi">
  </a>
  <a href="https://github.com/sekaibot-dev/sekaibot/">
    <img src="https://img.shields.io/github/stars/sekaibot-dev/sekaibot?style=social" alt="github">
  </a>
  <br />
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="black">
  </a>
  <a href="https://github.com/astral-sh/ruff">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="ruff">
  </a>
  <a href="https://github.com/pylint-dev/pylint">
    <img src="https://img.shields.io/badge/linting-pylint-blue" alt="pylint">
  </a>
  <a href="https://github.com/Microsoft/pyright">
    <img src="https://img.shields.io/badge/type%20checker-pyright-yellowgreen" alt="pyright">
  </a>
  <a href="https://github.com/python/mypy">
    <img src="https://img.shields.io/badge/type%20checker-mypy-blue" alt="mypy">
  </a>
  <br />
  <a href="https://codecov.io/gh/AliceBotProject/alicebot">
    <img src="https://codecov.io/gh/AliceBotProject/alicebot/graph/badge.svg?token=3H6ZU6NN0J" alt="codecov">
  </a>
  <a href="https://github.com/AliceBotProject/alicebot/actions/workflows/test.yml">
    <img src="https://github.com/AliceBotProject/alicebot/actions/workflows/test.yml/badge.svg?branch=master&event=push" alt="github">
  </a>
  <a href="https://github.com/AliceBotProject/alicebot/actions/workflows/lint.yml">
    <img src="https://github.com/AliceBotProject/alicebot/actions/workflows/lint.yml/badge.svg?branch=master&event=push" alt="github">
  </a>
  <a href="https://github.com/AliceBotProject/alicebot/actions/workflows/docs.yml">
    <img src="https://github.com/AliceBotProject/alicebot/actions/workflows/docs.yml/badge.svg?branch=master&event=push" alt="github">
  </a>
  <br />
  <a href="https://jq.qq.com/?_wv=1027&k=ZbE3p6tq">
    <img src="https://img.shields.io/badge/QQ%E7%BE%A4-834922207-orange" alt="qq-group">
  </a>
</div>
